@@ -23,8 +23,8 @@
  ***************************************************************************/
 #include "tool_setup.h"
 
-#if defined(_WIN32) && !defined(UNDER_CE)
-#  include <direct.h>
+#ifdef _WIN32
+#include <direct.h>
 #endif
 
 #include "tool_dirhie.h"
