@@ -27,11 +27,11 @@
 
 #define print_err(name, exp)                                            \
   curl_mfprintf(stderr, "Type mismatch for CURLOPT_%s (expected %s)\n", \
-                name, exp);
+                name, exp)
 
-static CURLcode test_lib1912(char *URL)
+static CURLcode test_lib1912(const char *URL)
 {
-/* Only test if GCC typechecking is available */
+/* Only test if GCC/clang type checking is available */
   int error = 0;
 #ifdef CURLINC_TYPECHECK_GCC_H
   const struct curl_easyoption *o;
@@ -73,7 +73,6 @@ static CURLcode test_lib1912(char *URL)
       print_err(o->name, "CURLOT_OBJECT");
       error++;
     }
-    /* Todo: no gcc typecheck for CURLOPTTYPE_BLOB types? */
   }
 #endif
   (void)URL;
